summaryrefslogtreecommitdiffstats
path: root/kmail/jobscheduler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/jobscheduler.cpp')
-rw-r--r--kmail/jobscheduler.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/jobscheduler.cpp b/kmail/jobscheduler.cpp
index 89cabec9..caf4759f 100644
--- a/kmail/jobscheduler.cpp
+++ b/kmail/jobscheduler.cpp
@@ -16,11 +16,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -34,8 +34,8 @@
using namespace KMail;
-JobScheduler::JobScheduler( TQObject* parent, const char* name )
- : TQObject( parent, name ), mTimer( this, "mTimer" ),
+JobScheduler::JobScheduler( TQObject* tqparent, const char* name )
+ : TQObject( tqparent, name ), mTimer( this, "mTimer" ),
mPendingImmediateTasks( 0 ),
mCurrentTask( 0 ), mCurrentJob( 0 )
{
@@ -109,7 +109,7 @@ void JobScheduler::notifyOpeningFolder( KMFolder* folder )
} else {
// Jobs scheduled from here should always be cancellable.
// One exception though, is when ExpireJob does its final KMMoveCommand.
// Then that command shouldn't kill its own parent job just because it opens a folder...
if ( mCurrentJob->isCancellable() )
interruptCurrentTask();
}
@@ -109,7 +109,7 @@ void JobScheduler::notifyOpeningFolder( KMFolder* folder )
// Jobs scheduled from here should always be cancellable.
// One exception though, is when ExpireJob does its final KMMoveCommand.
- // Then that command shouldn't kill its own parent job just because it opens a folder...
+ // Then that command shouldn't kill its own tqparent job just because it opens a folder...
if ( mCurrentJob->isCancellable() )
interruptCurrentTask();